@@ -1,10 +1,9 @@
-from jacdac.devtools import create_dev_tools_bus
+from ..bus import Bus
 from .server import RealTimeClockServer
 from time import sleep, localtime
 
 if __name__ == '__main__':
-    bus = create_dev_tools_bus(
-        device_description='real time clock server test')
+    bus = Bus()
 
     clock = RealTimeClockServer(bus)
     while True:
